# ligo-requests

ligo-requests provides a generic REST API client for the LIGO/Virgo services.
It uses the powerful [Requests](http://requests.readthedocs.io/) package for
reliable and high-throughput HTTP connection pooling.
